==> vdr-plugin-spider_0.1.1.orig.tar.gz: spider-0.1.1/i18n.c <==
/*
 * Spider-Arachnid: A plugin for the Video Disk Recorder
 *
 * See the README file for copyright information and how to reach the author.
 *
 * $Id: i18n.c 2 2005-05-14 22:25:56Z tom $
 */

#include "i18n.h"
#include <vdr/config.h>


const tI18nPhrase Phrases[] = {
  { "Spider Arachnid", // English
    "Spider Arachnid", // Deutsch / German
    "", // Slovenski / Slovenian
    "", // Italiano / Italian
    "", // Nederlands / Dutch
    "", // Portugus / Portuguese
    "", // Franais / French
    "", // Norsk / Norwegian
    "", // suomi / Finnish
    "", // Polski / Polish
    "", // Espaol / Spanish
    "", //  / Greek
    "", // Svenska / Swedish
    "", // Romn / Romanian
    "", // Magyar / Hungarian
    "", // Catal / Catalanian
#if VDRVERSNUM > 10302
    "", //  / Russian
#if VDRVERSNUM > 10307
    "", // Hrvatski / Croatian
#if VDRVERSNUM > 10313
    "", // Eesti / Estonian
#if VDRVERSNUM > 10316
    "", // Dansk / Danish
#endif
#endif
#endif
#endif
  },
  { "Spider Arachnid - the best patience game", // English
    "Spider Arachnid - die beste Patience", // Deutsch / German
    "", // Slovenski / Slovenian
    "", // Italiano / Italian
    "", // Nederlands / Dutch
    "", // Portugus / Portuguese
    "", // Franais / French
    "", // Norsk / Norwegian
    "", // suomi / Finnish
    "", // Polski / Polish
    "", // Espaol / Spanish
    "", //  / Greek
    "", // Svenska / Swedish
    "", // Romn / Romanian
    "", // Magyar / Hungarian
    "", // Catal / Catalanian
#if VDRVERSNUM > 10302
    "", //  / Russian
#if VDRVERSNUM > 10307
    "", // Hrvatski / Croatian
#if VDRVERSNUM > 10313
    "", // Eesti / Estonian
#if VDRVERSNUM > 10316
    "", // Dansk / Danish
#endif
#endif
#endif
#endif
  },
  { "Variation", // English
    "Variante", // Deutsch / German
    "", // Slovenski / Slovenian
    "", // Italiano / Italian
    "", // Nederlands / Dutch
    "", // Portugus / Portuguese
    "", // Franais / French
    "", // Norsk / Norwegian
    "", // suomi / Finnish
    "", // Polski / Polish
    "", // Espaol / Spanish
    "", //  / Greek
    "", // Svenska / Swedish
    "", // Romn / Romanian
    "", // Magyar / Hungarian
    "", // Catal / Catalanian
#if VDRVERSNUM > 10302
    "", //  / Russian
#if VDRVERSNUM > 10307
    "", // Hrvatski / Croatian
#if VDRVERSNUM > 10313
    "", // Eesti / Estonian
#if VDRVERSNUM > 10316
    "", // Dansk / Danish
#endif
#endif
#endif
#endif
  },
  { "Mini (one deck)", // English
    "Mini (ein Blatt)", // Deutsch / German
    "", // Slovenski / Slovenian
    "", // Italiano / Italian
    "", // Nederlands / Dutch
    "", // Portugus / Portuguese
    "", // Franais / French
    "", // Norsk / Norwegian
    "", // suomi / Finnish
    "", // Polski / Polish
    "", // Espaol / Spanish
    "", //  / Greek
    "", // Svenska / Swedish
    "", // Romn / Romanian
    "", // Magyar / Hungarian
    "", // Catal / Catalanian
#if VDRVERSNUM > 10302
    "", //  / Russian
#if VDRVERSNUM > 10307
    "", // Hrvatski / Croatian
#if VDRVERSNUM > 10313
    "", // Eesti / Estonian
#if VDRVERSNUM > 10316
    "", // Dansk / Danish
#endif
#endif
#endif
#endif
  },
  { "Normal", // English
    "Normal", // Deutsch / German
    "", // Slovenski / Slovenian
    "", // Italiano / Italian
    "", // Nederlands / Dutch
    "", // Portugus / Portuguese
    "", // Franais / French
    "", // Norsk / Norwegian
    "", // suomi / Finnish
    "", // Polski / Polish
    "", // Espaol / Spanish
    "", //  / Greek
    "", // Svenska / Swedish
    "", // Romn / Romanian
    "", // Magyar / Hungarian
    "", // Catal / Catalanian
#if VDRVERSNUM > 10302
    "", //  / Russian
#if VDRVERSNUM > 10307
    "", // Hrvatski / Croatian
#if VDRVERSNUM > 10313
    "", // Eesti / Estonian
#if VDRVERSNUM > 10316
    "", // Dansk / Danish
#endif
#endif
#endif
#endif
  },
  { "Only complete suits are allowed to remove", // English
    "Nur vollstndige Stze knnen entfernt werden", // Deutsch / German
    "", // Slovenski / Slovenian
    "", // Italiano / Italian
    "", // Nederlands / Dutch
    "", // Portugus / Portuguese
    "", // Franais / French
    "", // Norsk / Norwegian
    "", // suomi / Finnish
    "", // Polski / Polish
    "", // Espaol / Spanish
    "", //  / Greek
    "", // Svenska / Swedish
    "", // Romn / Romanian
    "", // Magyar / Hungarian
    "", // Catal / Catalanian
#if VDRVERSNUM > 10302
    "", //  / Russian
#if VDRVERSNUM > 10307
    "", // Hrvatski / Croatian
#if VDRVERSNUM > 10313
    "", // Eesti / Estonian
#if VDRVERSNUM > 10316
    "", // Dansk / Danish
#endif
#endif
#endif
#endif
  },
  { "No cards left", // English
    "Keine Karten brig", // Deutsch / German
    "", // Slovenski / Slovenian
    "", // Italiano / Italian
    "", // Nederlands / Dutch
    "", // Portugus / Portuguese
    "", // Franais / French
    "", // Norsk / Norwegian
    "", // suomi / Finnish
    "", // Polski / Polish
    "", // Espaol / Spanish
    "", //  / Greek
    "", // Svenska / Swedish
    "", // Romn / Romanian
    "", // Magyar / Hungarian
    "", // Catal / Catalanian
#if VDRVERSNUM > 10302
    "", //  / Russian
#if VDRVERSNUM > 10307
    "", // Hrvatski / Croatian
#if VDRVERSNUM > 10313
    "", // Eesti / Estonian
#if VDRVERSNUM > 10316
    "", // Dansk / Danish
#endif
#endif
#endif
#endif
  },
  { "Deal not allowed with empty piles", // English
    "Neue Karten nur, wenn alle Reihen belegt", // Deutsch / German
    "", // Slovenski / Slovenian
    "", // Italiano / Italian
    "", // Nederlands / Dutch
    "", // Portugus / Portuguese
    "", // Franais / French
    "", // Norsk / Norwegian
    "", // suomi / Finnish
    "", // Polski / Polish
    "", // Espaol / Spanish
    "", //  / Greek
    "", // Svenska / Swedish
    "", // Romn / Romanian
    "", // Magyar / Hungarian
    "", // Catal / Catalanian
#if VDRVERSNUM > 10302
    "", //  / Russian
#if VDRVERSNUM > 10307
    "", // Hrvatski / Croatian
#if VDRVERSNUM > 10313
    "", // Eesti / Estonian
#if VDRVERSNUM > 10316
    "", // Dansk / Danish
#endif
#endif
#endif
#endif
  },
  { "Congratulations!\nPress OK to start a new game", // English
    "Herzlichen Glckwunsch!\nOK startet ein neues Spiel", // Deutsch / German
    "", // Slovenski / Slovenian
    "", // Italiano / Italian
    "", // Nederlands / Dutch
    "", // Portugus / Portuguese
    "", // Franais / French
    "", // Norsk / Norwegian
    "", // suomi / Finnish
    "", // Polski / Polish
    "", // Espaol / Spanish
    "", //  / Greek
    "", // Svenska / Swedish
    "", // Romn / Romanian
    "", // Magyar / Hungarian
    "", // Catal / Catalanian
#if VDRVERSNUM > 10302
    "", //  / Russian
#if VDRVERSNUM > 10307
    "", // Hrvatski / Croatian
#if VDRVERSNUM > 10313
    "", // Eesti / Estonian
#if VDRVERSNUM > 10316
    "", // Dansk / Danish
#endif
#endif
#endif
#endif
  },
  { NULL }
};

==> vdr-plugin-spider_0.1.3.orig.tar.gz: spider-0.1.3/i18n.c <==
/*
 * Spider-Arachnid: A plugin for the Video Disk Recorder
 *
 * See the README file for copyright information and how to reach the author.
 *
 * $Id: i18n.c 69 2007-02-23 20:44:13Z tom $
 *
 *
 * Translations provided by:
 *
 * Spanish     bittor from open7x0.org
 *
 */

#include "i18n.h"
#include <vdr/config.h>


const tI18nPhrase Phrases[] = {
  { "Spider Arachnid", // English
    "Spider Arachnid", // Deutsch / German
    "", // Slovenski / Slovenian
    "", // Italiano / Italian
    "", // Nederlands / Dutch
    "", // Portugus / Portuguese
    "", // Franais / French
    "", // Norsk / Norwegian
    "", // suomi / Finnish
    "", // Polski / Polish
    "Spider Arachnid", // Espaol / Spanish
    "", //  / Greek
    "", // Svenska / Swedish
    "", // Romn / Romanian
    "", // Magyar / Hungarian
    "", // Catal / Catalanian
    "", //  / Russian
    "", // Hrvatski / Croatian
    "", // Eesti / Estonian
    "", // Dansk / Danish
    "", // esky / Czech
  },
  { "Spider Arachnid - the best patience game", // English
    "Spider Arachnid - die beste Patience", // Deutsch / German
    "", // Slovenski / Slovenian
    "", // Italiano / Italian
    "", // Nederlands / Dutch
    "", // Portugus / Portuguese
    "", // Franais / French
    "", // Norsk / Norwegian
    "", // suomi / Finnish
    "", // Polski / Polish
    "Spider Arachnid - mejor juego paciencia", // Espaol / Spanish
    "", //  / Greek
    "", // Svenska / Swedish
    "", // Romn / Romanian
    "", // Magyar / Hungarian
    "", // Catal / Catalanian
    "", //  / Russian
    "", // Hrvatski / Croatian
    "", // Eesti / Estonian
    "", // Dansk / Danish
    "", // esky / Czech
  },
  { "Variation", // English
    "Variante", // Deutsch / German
    "", // Slovenski / Slovenian
    "", // Italiano / Italian
    "", // Nederlands / Dutch
    "", // Portugus / Portuguese
    "", // Franais / French
    "", // Norsk / Norwegian
    "", // suomi / Finnish
    "", // Polski / Polish
    "Variacin", // Espaol / Spanish
    "", //  / Greek
    "", // Svenska / Swedish
    "", // Romn / Romanian
    "", // Magyar / Hungarian
    "", // Catal / Catalanian
    "", //  / Russian
    "", // Hrvatski / Croatian
    "", // Eesti / Estonian
    "", // Dansk / Danish
    "", // esky / Czech
  },
  { "Mini (one deck)", // English
    "Mini (ein Blatt)", // Deutsch / German
    "", // Slovenski / Slovenian
    "", // Italiano / Italian
    "", // Nederlands / Dutch
    "", // Portugus / Portuguese
    "", // Franais / French
    "", // Norsk / Norwegian
    "", // suomi / Finnish
    "", // Polski / Polish
    "Mini (una baraja)", // Espaol / Spanish
    "", //  / Greek
    "", // Svenska / Swedish
    "", // Romn / Romanian
    "", // Magyar / Hungarian
    "", // Catal / Catalanian
    "", //  / Russian
    "", // Hrvatski / Croatian
    "", // Eesti / Estonian
    "", // Dansk / Danish
    "", // esky / Czech
  },
  { "Normal", // English
    "Normal", // Deutsch / German
    "", // Slovenski / Slovenian
    "", // Italiano / Italian
    "", // Nederlands / Dutch
    "", // Portugus / Portuguese
    "", // Franais / French
    "", // Norsk / Norwegian
    "", // suomi / Finnish
    "", // Polski / Polish
    "Normal", // Espaol / Spanish
    "", //  / Greek
    "", // Svenska / Swedish
    "", // Romn / Romanian
    "", // Magyar / Hungarian
    "", // Catal / Catalanian
    "", //  / Russian
    "", // Hrvatski / Croatian
    "", // Eesti / Estonian
    "", // Dansk / Danish
    "", // esky / Czech
  },
  { "Only complete suits are allowed to remove", // English
    "Nur vollstndige Stze knnen entfernt werden", // Deutsch / German
    "", // Slovenski / Slovenian
    "", // Italiano / Italian
    "", // Nederlands / Dutch
    "", // Portugus / Portuguese
    "", // Franais / French
    "", // Norsk / Norwegian
    "", // suomi / Finnish
    "", // Polski / Polish
    "Slo puede eliminar los palos completos", // Espaol / Spanish
    "", //  / Greek
    "", // Svenska / Swedish
    "", // Romn / Romanian
    "", // Magyar / Hungarian
    "", // Catal / Catalanian
    "", //  / Russian
    "", // Hrvatski / Croatian
    "", // Eesti / Estonian
    "", // Dansk / Danish
    "", // esky / Czech
  },
  { "No cards left", // English
    "Keine Karten brig", // Deutsch / German
    "", // Slovenski / Slovenian
    "", // Italiano / Italian
    "", // Nederlands / Dutch
    "", // Portugus / Portuguese
    "", // Franais / French
    "", // Norsk / Norwegian
    "", // suomi / Finnish
    "", // Polski / Polish
    "No dej cartas", // Espaol / Spanish
    "", //  / Greek
    "", // Svenska / Swedish
    "", // Romn / Romanian
    "", // Magyar / Hungarian
    "", // Catal / Catalanian
    "", //  / Russian
    "", // Hrvatski / Croatian
    "", // Eesti / Estonian
    "", // Dansk / Danish
    "", // esky / Czech
  },
  { "Deal not allowed with empty piles", // English
    "Neue Karten nur, wenn alle Reihen belegt", // Deutsch / German
    "", // Slovenski / Slovenian
    "", // Italiano / Italian
    "", // Nederlands / Dutch
    "", // Portugus / Portuguese
    "", // Franais / French
    "", // Norsk / Norwegian
    "", // suomi / Finnish
    "", // Polski / Polish
    "Reparto no permitido con montones vacos", // Espaol / Spanish
    "", //  / Greek
    "", // Svenska / Swedish
    "", // Romn / Romanian
    "", // Magyar / Hungarian
    "", // Catal / Catalanian
    "", //  / Russian
    "", // Hrvatski / Croatian
    "", // Eesti / Estonian
    "", // Dansk / Danish
    "", // esky / Czech
  },
  { "Congratulations!\nPress OK to start a new game", // English
    "Herzlichen Glckwunsch!\nOK startet ein neues Spiel", // Deutsch / German
    "", // Slovenski / Slovenian
    "", // Italiano / Italian
    "", // Nederlands / Dutch
    "", // Portugus / Portuguese
    "", // Franais / French
    "", // Norsk / Norwegian
    "", // suomi / Finnish
    "", // Polski / Polish
    "Felicidades!\nPulse OK para iniciar un nuevo juego", // Espaol / Spanish
    "", //  / Greek
    "", // Svenska / Swedish
    "", // Romn / Romanian
    "", // Magyar / Hungarian
    "", // Catal / Catalanian
    "", //  / Russian
    "", // Hrvatski / Croatian
    "", // Eesti / Estonian
    "", // Dansk / Danish
    "", // esky / Czech
  },
  { NULL }
};
